@@ -32,7 +32,7 @@ class RlStepSeq():
     model_states: typing.Optional[xr.DataArray]
     rewards:      xr.DataArray  
     dones:        xr.DataArray
-    custom:       dict[str, xr.DataArray]
+    custom:       typing.Dict[str, xr.DataArray]
 
 def run_rollout(
         model_or_func, 
@@ -270,4 +270,4 @@ if __name__ == "__main__":
     # Test with a procgen gym3 env
     import procgen
     env = procgen.ProcgenEnv(num_envs=1, env_name='maze', num_levels=1, start_level=0)
-    seq, episode_returns, step_cnt = run_rollout(predict, env, max_steps=50)
\ No newline at end of file
+    seq, episode_returns, step_cnt = run_rollout(predict, env, max_steps=50)
